package djmil.cordacheckers.user;

import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.security.core.userdetails.UserDetailsService;
import org.springframework.security.core.userdetails.UsernameNotFoundException;
import org.springframework.security.crypto.password.PasswordEncoder;
import org.springframework.stereotype.Service;

@Service
public class UserService implements UserDetailsService {

    private final PasswordEncoder encoder;
    private final HoldingIdentityResolver holdingIdentityResolver;

    public UserService(
		    PasswordEncoder encoder,
		    HoldingIdentityResolver holdingIdentityResolver) {
        this.encoder = encoder;
        this.holdingIdentityResolver = holdingIdentityResolver;
    }

    @Override
    public User loadUserByUsername(String username) throws UsernameNotFoundException {
        final var holdingIdentity = this.holdingIdentityResolver.getByUsername(username);
        if (holdingIdentity == null) {
            throw new UsernameNotFoundException("Can't find HoldingIdentity for the user '"+username+ "'");
        }

        System.out.println("Load user "+username);
        
        org.springframework.security.core.userdetails.User.UserBuilder userBuilder = org.springframework.security.core.userdetails.User.builder();
        UserDetails baseUser = userBuilder
            .username(username)
            .password(this.encoder.encode("qaz123"))
            .build();
        
        return new User(baseUser, holdingIdentity);
    }
}
